import { forwardRef, useEffect, useImperativeHandle, useRef } from 'react';

export default forwardRef(function Input(
    { type = 'text', className = '', isFocused = false, ...props },
    ref,
) {
    const localRef = useRef(null);

    useImperativeHandle(ref, () => ({
        focus: () => localRef.current?.focus(),
    }));

    useEffect(() => {
        if (isFocused) {
            localRef.current?.focus();
        }
    }, [isFocused]);

    return (
        <input
            {...props}
            type={type}
            className={`rounded-lg py-[4px] border border-border focus:border-border focus:ring-border lg:text-[.8rem] sm:text-lg bg-background-secondary w-full ${className}`}
            ref={localRef}
        />
    );
});